This is a guide to using the STIG checker for the pfsense firewall.
All paths here will be relative to the root of the git repo unless otherwise
specified.

## Generating FIREWALL.ckl (and other template .ckl files)
Download:
  1) the STIG viewer from the DISA website.  It is a .jar file.
  2) the `.zip` folder corresponding to your STIG.  This should contain
  many files but you are primarily interested in the `.xml` in this folder.

Then, launch the STIG viewer.  Import your STIG which is the
`.xml` file in the `.zip` folder .  You will then have the
opporunity to export or save your changes in the form of a .ckl file.
Do this and the resulting file is your template .ckl file.

**IMPORTANT** - Rename this FIREWALL.ckl and place it in srg/firewall.

## Tool Usage
You can either use check-pfsense-stig.py in a development environment
or in a production environment (on the actual firewall).

### Development Environment
First, if you have not already make sure to read the guide to setting up
the (development environment)[Vagrant/README.md].

Make sure to do a `sudo pip3 install -r requirements.txt` in order
to get the python3 dependencies for this application.

Start by launching your pfsense virtual machine in virtual box.
If you read and followed the directions in the guide, this should
already be configured properly.

Then do a `vagrant up` in the folder `srg/firewall/Vagrant/`.
Then `vagrant ssh` in order to get onto the vagrant guest.

In the vagrant guest terminal,
run `./check-stig-pfsense.py --all --run_ssh`
The output of the command (FIREWALL.ckl) will be placed in the folder containing
this README.
There will also be output to stdout.

### Prod Environment
Remember to install the python3 dependencies and to do
a git clone of this repository.
Then edit srg/firewall/util.py to make sure the private key
path accurately reflects the path to private key that will allow 
you to access root on the pfsense firewall.
Then edit the variable that corresponds to the IP address of the firewall.

Last, make sure that the public key on your host is added to the
`~/.ssh/authorized_keys` file on the pfsense firewall.
From there you can run `./check-stig-pfsense.py --all --run_ssh`

## Calculating Current Status of STIG checking developing
Simply run `./status.sh`.  This will print out which
vulnerability IDs are In Progress, Not Started, and Done.

## Firewall Rules

[     ] (Rule V-3000)[V-3000.py]: The network device must log all interface access control lists (ACL) deny statements.

[     ] (Rule V-3008)[V-3008.py]: The IAO will ensure IPSec VPNs are established as tunnel type VPNs when transporting management traffic across an ip backbone network.

[     ] (Rule V-3012)[V-3012.py]: Network devices must be password protected.

[     ] (Rule V-3013)[V-3013.py]: Network devices must display the DoD-approved logon banner warning.

[     ] (Rule V-3014)[V-3014.py]: The network devices must timeout management connections for administrative access after 10 minutes or less of inactivity.

[     ] (Rule V-3020)[V-3020.py]: Network devices must have DNS servers defined if it is configured as a client resolver.

[     ] (Rule V-3021)[V-3021.py]: Network devices must only allow SNMP access from addresses belonging to the management network.

[     ] (Rule V-3043)[V-3043.py]: The network device must use different SNMP community names or groups for various levels of read and write access.

[     ] (Rule V-3054)[V-3054.py]: The firewall must not utilize any services or capabilities that are not necessary for the administration of the firewall.

[     ] (Rule V-3056)[V-3056.py]: Group accounts must not be configured for use on the network device.

[     ] (Rule V-3057)[V-3057.py]: Authorized accounts must be assigned the least privilege level necessary to perform assigned duties.

[     ] (Rule V-3058)[V-3058.py]: Unauthorized accounts must not be configured for access to the network device.

[     ] (Rule V-3062)[V-3062.py]: Network devices must be configured to ensure passwords are not viewable when displaying configuration information.

[     ] (Rule V-3069)[V-3069.py]: Management connections to a network device must be established using secure protocols with FIPS 140-2 validated cryptographic modules.

[     ] (Rule V-3070)[V-3070.py]: Network devices must log all attempts to establish a management connection for administrative access.

[     ] (Rule V-3085)[V-3085.py]: Network devices must have HTTP service for administrative access disabled.

[     ] (Rule V-3143)[V-3143.py]: Network devices must not have any default manufacturer passwords.

[     ] (Rule V-3156)[V-3156.py]: The device must be configured to protect the network against denial of service attacks such as Ping of Death, TCP SYN floods, etc.

[     ] (Rule V-3160)[V-3160.py]: Network devices must be running a current and supported operating system with all IAVMs addressed.

[     ] (Rule V-3175)[V-3175.py]: The network device must require authentication prior to establishing a management connection for administrative access.

[     ] (Rule V-3176)[V-3176.py]: The network devices must be configured to alert the administrator of a potential attack or system failure.

[     ] (Rule V-3178)[V-3178.py]: Administrator logons, changes to the administrator group, and account lockouts must be logged.

[     ] (Rule V-3196)[V-3196.py]: The network device must use SNMP Version 3 Security Model with FIPS 140-2 validated cryptography for any SNMP agent configured on the device.

[     ] (Rule V-3210)[V-3210.py]: The network device must not use the default or well-known SNMP community strings public and private.

[     ] (Rule V-3966)[V-3966.py]: In the event the authentication server is unavailable, the network device must have a single local account of last resort defined.

[     ] (Rule V-3967)[V-3967.py]: The network devices must time out access to the console port at 10 minutes or less of inactivity.

[     ] (Rule V-3969)[V-3969.py]: Network devices must only allow SNMP read-only access.

[     ] (Rule V-3982)[V-3982.py]: L2TP must not pass into the private network of an enclave.

[     ] (Rule V-4582)[V-4582.py]: The network device must require authentication for console access.

[     ] (Rule V-4619)[V-4619.py]: The FA will ensure that if the firewall product operates on an OS platform, the host must be STIG compliant prior to the installation of the firewall product.

[     ] (Rule V-5611)[V-5611.py]: The network devices must only allow management connections for administrative access from hosts residing in the management network.

[     ] (Rule V-5612)[V-5612.py]: The network devices must be configured to timeout after 60 seconds or less for incomplete or broken SSH sessions.

[     ] (Rule V-5613)[V-5613.py]: The network device must be configured for a maximum number of unsuccessful SSH logon attempts set at 3 before resetting the interface.

[     ] (Rule V-5646)[V-5646.py]: The network device must drop half-open TCP connections through filtering thresholds or timeout periods.

[     ] (Rule V-5731)[V-5731.py]: The SA will utilize ingress and egress ACLs to restrict traffic destined to the enclave perimeter in accordance with the guidelines contained in DoD Instruction 8551.1 for all ports and protocols required for operational commitments. 

[     ] (Rule V-7011)[V-7011.py]: The auxiliary port must be disabled unless it is connected to a secured modem providing encryption and authentication.

[     ] (Rule V-14637)[V-14637.py]: Router advertisements must be suppressed on all external-facing IPv6-enabled interfaces.

[     ] (Rule V-14643)[V-14643.py]: The SA must configure the firewall for the minimum content  and protocol inspection requirements.

[     ] (Rule V-14644)[V-14644.py]: The firewall must reject requests for access or services where the source address received by the firewall specifies a loopback address.

[     ] (Rule V-14646)[V-14646.py]: Alerts must be automatically generated to notify the administrator when log storage reaches seventy-five percent or more of its maximum capacity.

[     ] (Rule V-14647)[V-14647.py]: The network device must dump logs when they reach 75% capacity to a syslog server.

[     ] (Rule V-14648)[V-14648.py]: Critical alerts must be generated and notifications sent to authorized personnel regardless if the person is logged in.

[     ] (Rule V-14649)[V-14649.py]: The ISSO must ensure the message is displayed at the remote console if an administrator is already logged in, or when an administrator logs in if the alarm message has not been acknowledged.

[     ] (Rule V-14653)[V-14653.py]: The ISSO must ensure the alarm message identifying the potential security violation makes accessible the audit record contents associated with the event(s).

[     ] (Rule V-14655)[V-14655.py]: The ISSO must ensure an alert will remain written on the consoles until acknowledged by an administrator.

[     ] (Rule V-14656)[V-14656.py]: The ISSO must ensure an acknowledgement message identifying a reference to the potential security violation is logged and it contains a notice that it has been acknowledged, the time of the acknowledgement and the user identifier that acknowledged the alarm, at the remote administrator session that received the alarm.

[     ] (Rule V-14667)[V-14667.py]: Network devices must be configured with rotating keys used for authenticating IGP peers that have a duration of 180 days or less.

[     ] (Rule V-14671)[V-14671.py]: Network devices must authenticate all NTP messages received from NTP servers and peers.

[     ] (Rule V-14693)[V-14693.py]: The network device must be configured to ensure IPv6 Site Local Unicast addresses are not defined in the enclave, (FEC0::/10). Note that this consist of all addresses that begin with FEC, FED, FEE and FEF.

[     ] (Rule V-14717)[V-14717.py]: The network device must not allow SSH Version 1 to be used for administrative access.

[     ] (Rule V-15294)[V-15294.py]: Teredo packets must be blocked inbound to the enclave and outbound from the enclave.

[     ] (Rule V-15296)[V-15296.py]: Interfaces supporting IPv4 in NAT-PT Architecture must not receive IPv6 traffic.

[     ] (Rule V-15432)[V-15432.py]: Network devices must use two or more authentication servers for the purpose of granting administrative access.

[     ] (Rule V-15434)[V-15434.py]: The emergency administration account must be set to an appropriate authorization level to perform necessary administrative functions when the authentication server is not online.

[     ] (Rule V-17754)[V-17754.py]: Management traffic is not restricted to only the authorized management packets based on destination and source IP address.   

[     ] (Rule V-17814)[V-17814.py]: Gateway configuration at the remote VPN end-point is a not a mirror of the local gateway 

[     ] (Rule V-17821)[V-17821.py]: The network devices OOBM interface must be configured with an OOBM network address.

[     ] (Rule V-17822)[V-17822.py]: The network devices management interface must be configured with both an ingress and egress ACL.

[     ] (Rule V-17823)[V-17823.py]: The management interface must be configured as passive for the IGP instance deployed in the managed network.

[     ] (Rule V-17830)[V-17830.py]: The firewall located behind the premise router must be configured to block all outbound management traffic.

[     ] (Rule V-17835)[V-17835.py]: Traffic entering the tunnels is not restricted to only the authorized management packets based on destination address. 

[     ] (Rule V-18522)[V-18522.py]: Server VLAN interfaces must be protected by restrictive ACLs using a deny-by-default security posture.

[     ] (Rule V-18523)[V-18523.py]: The IAO will ensure the Server Farm infrastructure is secured by ACLs on VLAN interfaces that restrict data originating from one server farm segment destined to another server farm segment.

[     ] (Rule V-18525)[V-18525.py]: The IAO will ensure the Server Farm VLANs are protected by severely restricting the actions the hosts can perform on the servers by firewall content filtering.

[     ] (Rule V-18608)[V-18608.py]: IPv6 6-to-4 addresses with a prefix of 2002::/16 must be filtered at the perimeter.

[     ] (Rule V-18815)[V-18815.py]: IPv6 Jumbo Payload hop by hop header must be blocked.

[     ] (Rule V-23747)[V-23747.py]: Network devices must use at least two NTP servers to synchronize time.

[     ] (Rule V-25037)[V-25037.py]: The IAO will ensure that the router or firewall software has been upgraded to mitigate the risk of DNS cache poisoning attack caused by a flawed PAT implementation using a predictable source port allocation method for DNS query traffic.

[     ] (Rule V-25890)[V-25890.py]: Network device logs must be timestamped.

[     ] (Rule V-25891)[V-25891.py]: Network device logs must include source IP, destination IP, port, protocol used and action taken.

[     ] (Rule V-28784)[V-28784.py]: A service or feature that calls home to the vendor must be disabled.

[     ] (Rule V-30638)[V-30638.py]: The IAO must ensure firewalls deployed in an IPv6 enclave meet the requirements defined by DITO and NSA milestone objective 3 guidance.

[     ] (Rule V-72881)[V-72881.py]: The firewall must not be listening for telnet service.

