#!/usr/bin/python3
import argparse
import sys
import os
import csv
import logging
import shutil
# custom made python module with helper methods
import util

# run from script dir
SCRIPT_DIR = os.path.dirname(os.path.abspath(sys.argv[0]))
os.chdir(SCRIPT_DIR)

def sanitize(s):
    return s.replace("%", "%%")

def print_findings(vuln, xml_out, findings):
    '''
    from srg.sh
    export vuln
    export comments=$(cat stdout)
    export details=$(cat stderr)
    perl -i -0pe 's/(?<=$ENV{vuln})(.*?)<COMMENTS><\/COMMENTS>/$1<COMMENTS>$ENV{comments}<\/COMMENTS>/s' $checklist
    perl -i -0pe 's/(?<=$ENV{vuln})(.*?)<FINDING_DETAILS><\/FINDING_DETAILS>/$1<FINDING_DETAILS>$ENV{details}<\/FINDING_DETAILS>/s' $checklist
    if [ ! -z "$details"  ]; then
        perl -i -0pe 's/(?<=$ENV{vuln})(.*?)<STATUS>Not_Reviewed<\/STATUS>/$1<STATUS>Open<\/STATUS>/s' $checklist
    else
        perl -i -0pe 's/(?<=$ENV{vuln})(.*?)<STATUS>Not_Reviewed<\/STATUS>/$1<STATUS>NotAFinding<\/STATUS>/s' $checklist
    '''
    # logging.info('Findings        : {}\n'.format(findings))
    comments = "perl -i -0pe 's/(?<={})(.*?)<COMMENTS><\/COMMENTS>/$1<COMMENTS>$ENV{{comments}}<\/COMMENTS>/s' {}"
    finding_details = "perl -i -0pe 's/(?<={})(.*?)<FINDING_DETAILS><\/FINDING_DETAILS>/$1<FINDING_DETAILS>$ENV{{details}}<\/FINDING_DETAILS>/s' {}"
    status = "perl -i -0pe 's/(?<={})(.*?)<STATUS>Not_Reviewed<\/STATUS>/$1<STATUS>{}<\/STATUS>/s' {}"
    os.environ["comments"] = findings.msg
    os.environ["details"] = findings.msg
    os.system(comments.format(vuln, xml_out))
    if findings.finding != util.PASS:
        print(findings, file=sys.stderr)
        os.system(finding_details.format(vuln, xml_out))
        os.system(status.format(vuln, "Open", xml_out))
    else:
        print(findings, file=sys.stdout)
        print("NotAFinding", file=sys.stdout)
        os.system(status.format(vuln, "NotAFinding", xml_out))

def main():

    parser = argparse.ArgumentParser(description='STIG check for firewall')
    with open(os.path.join(SCRIPT_DIR, "stigs.csv")) as stigs:
        csv_dict = list(csv.DictReader(stigs,
                                       delimiter="\t",
                                       dialect="excel"))

        for row in csv_dict:
            rule = row["rule"]
            desc = row["title"].replace("\n\n","\n").replace("\n","\n    ")
            desc = sanitize(desc)
            parser.add_argument('--{}'.format(rule.replace("-","_")),
                                            action='store_true',
                                            help='''{}'''.format(desc))

        parser.add_argument('-a',
                            '--all',
                            action='store_true',
                            help='''run all of the checks''')
        parser.add_argument('-r',
                            '--run_ssh',
                            action='store_true',
                            help='''Run SSH commands remotely on router. Make sure that you have populated router ip address and location of private key in util.py''')
        args = parser.parse_args()

        util.RUN_SSH = args.run_ssh

        log_filename='stig-check.log'
        root = logging.getLogger()
        root.setLevel(logging.INFO)

        ch1 = logging.StreamHandler(sys.stdout)
        ch2 = logging.StreamHandler(open(log_filename, "w"))
        root.addHandler(ch1)
        root.addHandler(ch2)
        xml_out = "FIREWALL.ckl"
        if os.path.exists(xml_out):
            os.remove(xml_out)
        shutil.copy("./FIREWALL_SRG_TEMPLATE.ckl", xml_out)
        if len(sys.argv[1:]) == 0:
            parser.print_help()
            sys.exit()


        for row in csv_dict:
            rule = row["rule"]
            desc = row["title"].replace("\n\n","\n").replace("\n","\n    ")
            desc = sanitize(desc)
            if args.all:
                rule_module = __import__(rule)
                logging.info('Vulnerability ID: {}'.format(rule))
                logging.info('Description     : {}'.format(desc))
                findings = rule_module.run(None)
                print_findings(rule, xml_out, findings)
            else:
                if args.__dict__[rule.replace("-", "_")]:
                    rule_module = __import__(rule)
                    logging.info('Vulnerability ID: {}'.format(rule))
                    logging.info('Description     : {}'.format(desc))
                    findings = rule_module.run(None)
                    print_findings(rule, xml_out, findings)

if __name__ == "__main__":
    main()
