#!/usr/bin/python
import sys
import os
import csv

# only run ONCE to generate V-*.py python scripts!
# gen-salt-files.py <csv>
# where csv has three columns
# rule\t title\t fixtext

MAX_LINE_LEN = 64
def break_newlines(longstr):
    broken = [longstr[MAX_LINE_LEN*i:MAX_LINE_LEN*(i+1)] for i, _ in enumerate(longstr[::MAX_LINE_LEN])]
    return "\n".join(map(lambda s: "#   " + s, broken))

def write_rule(rule, title, fix):
    with open("{}.py".format(rule), "w") as rule_out:
        rule_out.write("#!/usr/bin/python\n")
        rule_out.write("\n")
        rule_out.write("\n")
        rule_out.write("# Vulnerability {}\n".format(rule))
        rule_out.write("# Title\n{}\n".format(break_newlines(title)))
        rule_out.write("\n")
        rule_out.write("fix = ''' {} '''\n".format(fix))
        rule_out.write("\n")
        rule_out.write("\n")
        rule_out.write("import logging\n")
        rule_out.write("import util\n")
        rule_out.write("\n")
        rule_out.write("def run(xml_out):\n")
        rule_out.write("    f = util.Finding(util.UNIMPLEMENTED, 'Have not started yet')\n")
        rule_out.write("    return f\n")
        rule_out.write("\n")


def main():
    if len(sys.argv) != 2:
        print "USAGE: {} /path/to/csv".format(sys.argv[0])
        sys.exit(1)
    fname = sys.argv[1]
    os.chdir(os.path.dirname(sys.argv[0]))

    stig_dict = csv.DictReader(open(fname).read().split("\n"),
                               delimiter="\t")
    with open("README.md", "w") as md_out:
        md_out.write("## Firewall Rules\n\n")
        for line in stig_dict:
            rule, title, fix = line["rule"], line["title"], line["fixtext"]
            write_rule(rule, title, fix)
            md_out.write("[     ] (Rule {})[{}.py]: {}\n\n".format(rule, rule, title))

if __name__ == "__main__":
    main()
